@@ -31,7 +31,8 @@ describe 'nova' do
         :refreshonly => true
       )}
 
-      it 'configures glance api servers' do
+      it 'configures image service' do
+        is_expected.to contain_nova_config('DEFAULT/image_service').with_value('nova.image.glance.GlanceImageService')
         is_expected.to contain_nova_config('glance/api_servers').with_value('http://localhost:9292')
       end
 
@@ -65,9 +66,6 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/cpu_allocation_ratio').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/ram_allocation_ratio').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/disk_allocation_ratio').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('DEFAULT/ssl_only').with_value(false)
-        is_expected.to contain_nova_config('DEFAULT/cert').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('DEFAULT/key').with_value('<SERVICE DEFAULT>')
       end
 
       it 'configures block_device_allocate params' do
@@ -79,8 +77,9 @@ describe 'nova' do
     context 'with overridden parameters' do
 
       let :params do
-        {
-          :glance_api_servers                      => 'http://localhost:9292',
+        { :debug                                   => true,
+          :log_dir                                 => '/var/log/nova2',
+          :image_service                           => 'nova.image.local.LocalImageService',
           :default_transport_url                   => 'rabbit://rabbit_user:password@localhost:5673',
           :rpc_response_timeout                    => '30',
           :control_exchange                        => 'nova',
@@ -100,6 +99,7 @@ describe 'nova' do
           :notification_driver                     => 'ceilometer.compute.nova_notifier',
           :notification_topics                     => 'openstack',
           :notification_format                     => 'unversioned',
+          :notify_on_api_faults                    => true,
           :report_interval                         => '60',
           :os_region_name                          => 'MyRegion',
           :use_ipv6                                => true,
@@ -116,9 +116,6 @@ describe 'nova' do
           :block_device_allocate_retries           => '60',
           :block_device_allocate_retries_interval  => '3',
           :my_ip                                   => '192.0.2.1',
-          :ssl_only                                => true,
-          :cert                                    => '/etc/ssl/private/snakeoil.pem',
-          :key                                     => '/etc/ssl/certs/snakeoil.pem',
         }
       end
 
@@ -133,8 +130,9 @@ describe 'nova' do
         })
       end
 
-      it 'configures glance api servers' do
-        is_expected.to contain_nova_config('glance/api_servers')
+      it 'configures image service' do
+        is_expected.to contain_nova_config('DEFAULT/image_service').with_value('nova.image.local.LocalImageService')
+        is_expected.to_not contain_nova_config('glance/api_servers')
       end
 
       it 'configures auth_strategy' do
@@ -184,12 +182,10 @@ describe 'nova' do
         is_expected.to contain_nova_config('oslo_messaging_notifications/driver').with_value('ceilometer.compute.nova_notifier')
         is_expected.to contain_nova_config('oslo_messaging_notifications/topics').with_value('openstack')
         is_expected.to contain_nova_config('notifications/notification_format').with_value('unversioned')
+        is_expected.to contain_nova_config('notifications/notify_on_api_faults').with_value(true)
         is_expected.to contain_nova_config('DEFAULT/report_interval').with_value('60')
         is_expected.to contain_nova_config('os_vif_linux_bridge/use_ipv6').with_value('true')
         is_expected.to contain_nova_config('cinder/os_region_name').with_value('MyRegion')
-        is_expected.to contain_nova_config('DEFAULT/ssl_only').with_value(true)
-        is_expected.to contain_nova_config('DEFAULT/cert').with_value('/etc/ssl/private/snakeoil.pem')
-        is_expected.to contain_nova_config('DEFAULT/key').with_value('/etc/ssl/certs/snakeoil.pem')
       end
 
       context 'with multiple notification_driver' do
@@ -226,6 +222,17 @@ describe 'nova' do
       end
     end
 
+    context 'with deprecated notify_api_faults parameter' do
+      let :params do
+        { :notify_on_api_faults => :undef,
+          :notify_api_faults    => 'true' }
+      end
+
+      it 'configures notify_on_api_faults using the deprecated parameter' do
+        is_expected.to contain_nova_config('notifications/notify_on_api_faults').with_value('true')
+      end
+    end
+
     context 'with rabbit_hosts parameter' do
       let :params do
         { :rabbit_hosts => ['rabbit:5673', 'rabbit2:5674'] }
@@ -365,7 +372,7 @@ describe 'nova' do
       end
     end
 
-    context 'with amqp overriden parameters' do
+    context 'with amqp overridden parameters' do
       let :params do
         { :amqp_idle_timeout  => '60',
           :amqp_trace         => true,
